# API Reference

## Overview
```{eval-rst}
.. automodule:: datanavigator
    :members:
    :special-members: __getitem__
```

## Browsers
```{eval-rst}
.. automodule:: datanavigator.core
    :members:
    :undoc-members:
```

```{eval-rst}
.. automodule:: datanavigator.signals
    :members:
    :undoc-members:
```

```{eval-rst}
.. automodule:: datanavigator.plots
    :members:
    :undoc-members:
```

```{eval-rst}
.. automodule:: datanavigator.videos
    :members:
    :undoc-members:
```

```{eval-rst}
.. automodule:: datanavigator.components
    :members:
    :undoc-members:
```

## Assets

Assets that power the functionality of the `GenericBrowser` class.

```{eval-rst}
.. automodule:: datanavigator.assets
    :members:
    :undoc-members:
    :exclude-members: ERROR_INVALID_NAME
```

```{eval-rst}
.. automodule:: datanavigator.events
    :members:
    :undoc-members:
    :exclude-members: ERROR_INVALID_NAME
```

## Utilities
```{eval-rst}
.. automodule:: datanavigator.utils
    :members:
    :undoc-members:
    :exclude-members: ERROR_INVALID_NAME
```

## Optical flow
```{eval-rst}
.. automodule:: datanavigator.opticalflow
    :members:
    :undoc-members:
```

## Point Tracking
```{eval-rst}
.. automodule:: datanavigator.pointtracking
    :members:
    :undoc-members:
```